//Servo motors need to be connect to the following PWM channels for this code.
//-Index Finger:
//  -Tip:       0
//  -Middle:    1
//  -Bottom:    2
//-Middle Finger:
//  -Tip:       3
//  -Middle:    4
//  -Bottom:    5
//-Ring Finger:
//  -Tip:       6
//  -Middle:    7
//  -Bottom:    8
//-Pinky Finger:
//  -Tip:       9
//  -Middle:    10
//  -Bottom:    11
//-Thumb:
//  -Joint:     12
//-Wrist:
//  -Bending:   13
//  -Rotation:  14
//-Elbow:
//  -Joint:     15

#include <Wire.h>
#include <Adafruit_PWMServoDriver.h>
#include <SoftwareSerial.h>
#include "SimpleVR.h"

VR myVR(2,7);    // 7:RX 2:TX, you can choose your favourite pins.
uint8_t buf[64];

uint8_t sta;

//define voice commands
#define ALFA     (1)
#define BRAVO    (2)
#define CHARLIE  (3)
#define DELTA    (4)
#define ECHO     (5)
#define FOXTROT  (6)
#define GOLF     (7)
#define HOTEL    (8)
#define INDIA    (9)
#define JULIETT  (10)
#define KILO     (11)
#define LIMA     (12)
#define MIKE     (13)
#define NOVEMBER (14)
#define OSCAR    (15)
#define PAPA     (16)
#define QUEBEC   (17)
#define ROMEO    (18)
#define SIERRA   (19)
#define TANGO    (20)
#define UNIFORM  (21)
#define VICTOR   (22)
#define WHISKY   (23)
#define XRAY     (24)
#define YANKEE   (25)
#define ZULU     (26)

//define motor shield
#define   SERVO_FREQ            50
#define   SERVOMIN              150
#define   SERVOMAX              600
#define   USMIN                 600
#define   USMAX                 1250

#define   MIN_PULSE_WIDTH       150
#define   MAX_PULSE_WIDTH       600
#define   DEFAULT_PULSE_WIDTH   600
#define   FREQUENCY             50
Adafruit_PWMServoDriver pwm = Adafruit_PWMServoDriver();


void setup(void)
// voice recognition setup
{
  myVR.begin(9600);
  
  /** initialize */
  Serial.begin(115200);
  Serial.println(F("Elechouse SimpleVR Module test sample."));
  Serial.println(F("Command index would be displayed here if it is called."));
  
  if(myVR.checkVersion(buf) > 0){
    Serial.println(F("Found SimpleVR"));
    Serial.print(F("SW VER:"));
    Serial.print(buf[0], DEC); 
    Serial.print('.');Serial.print(buf[1], DEC); 
    Serial.print('.');Serial.println(buf[2], DEC); 
    Serial.print(F("HW VER:"));
    Serial.print(buf[3], DEC); 
    Serial.print('.');Serial.println(buf[4], DEC); 
  }else{
    Serial.println(F("Can't find SimpleVR, please restart Arduino after checking the connection."));
    while(1);
  }
  
  if(myVR.setGroup(1) < 0){
    Serial.println(F("Communication error, please restart Arduino after checking the connection."));
    while(1);
  }
  
  if(myVR.setEnable(true) < 0){
    Serial.println(F("Communication error, please restart Arduino after checking the connection."));
    while(1);
  }
  
  if(myVR.checkSystemSettings(buf) < 0){
    Serial.println(F("Communication error, please restart Arduino after checking the connection."));
    while(1);
  }else{
    if(buf[0]){
      Serial.println(F("SimpleVR is enabled."));
    }else{
      Serial.println(F("SimpleVR is disabled."));
    }
    Serial.print(F("Group "));
    Serial.print(buf[1], DEC); Serial.println(F(" is selected."));
    if(buf[2] != 0xFF){
      Serial.print(F("Threshold value is ")); Serial.println(buf[2], DEC);
      Serial.println();
    }
  }
  //motor shield setup
  pwm.begin();
  pwm.setOscillatorFrequency(27000000);
  pwm.setPWMFreq(FREQUENCY);
  delay(10);
}


void loop(void){
  int ret;
  uint16_t voice=0;
  ret = myVR.recognize(buf, 50);
  if(ret > 0){
    voice += buf[0];
    voice <<=8;
    voice += buf[1];
    Serial.println(voice, DEC);
    
  switch(voice){
    case ALFA:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        }
        delay(2500);
    break;

    case BRAVO:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(12, 1450);
        }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(12, 600);
        }
        delay(2500);
    break;

    case CHARLIE:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(9, microsec);
        pwm.writeMicroseconds(12, microsec);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(9, microsec);
        pwm.writeMicroseconds(12, microsec);
       }
       delay(2500);
    break;

    case DELTA:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 1100);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 600);
       }
       delay(2500);
    break;

    case ECHO:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(9, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(12, 1450);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(12, 600);
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(9, microsec);
        pwm.writeMicroseconds(10, microsec);
       }
       delay(2500);
    break;

    case FOXTROT:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(12, 1100);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(12, 600);
       }
       delay(2500);
    break;

    case GOLF:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 1100);
        pwm.writeMicroseconds(13, 1000);
        pwm.writeMicroseconds(14, 800);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 600);
        pwm.writeMicroseconds(13, 600);
        pwm.writeMicroseconds(14, 1500);
       }
       delay(2500);
    break;

    case HOTEL:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 1100);
        pwm.writeMicroseconds(13, 1000);
        pwm.writeMicroseconds(14, 800);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 600);
        pwm.writeMicroseconds(13, 600);
        pwm.writeMicroseconds(14, 1500);
       }
       delay(2500);
    break;

    case INDIA:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        
       }
       delay(2500);
    break;

    case JULIETT:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(13, 1000);
        pwm.writeMicroseconds(14, 800);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(13, 600);
        pwm.writeMicroseconds(14, 1500);
       }
       delay(2500);
    break;

    case KILO:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 1100);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 600);
       }
       delay(2500);
    break;

    case LIMA:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;

    case MIKE:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        //delay();
        pwm.writeMicroseconds(12, 1450);
        //delay();
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(1, microsec);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        //delay();
        pwm.writeMicroseconds(12, 600);
        //delay();
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(10, microsec);
       }
       delay(2500);
    break;

    case NOVEMBER:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(7, microsec);
        //delay();
        pwm.writeMicroseconds(12, 1300);
        //delay();
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(1, microsec);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        //delay();
        pwm.writeMicroseconds(12, 600);
        //delay();
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;

    case OSCAR:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(12, 1100);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(12, 600);
       }
       delay(2500);
    break;

    case PAPA:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 1100);
        pwm.writeMicroseconds(13, 1000);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 600);
        pwm.writeMicroseconds(13, 600);
       }
       delay(2500);
    break;

    case QUEBEC:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 1100);
        pwm.writeMicroseconds(13, 1000);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        pwm.writeMicroseconds(12, 600);
        pwm.writeMicroseconds(13, 600);
       }
       delay(2500);
    break;

    case ROMEO:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){

       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){

       }
       delay(2500);
    break;

    case SIERRA:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(9, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        //delay();
        pwm.writeMicroseconds(12, 1450);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(12, 600);
        //delay();
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(3, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(6, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(9, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;

    case TANGO:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        //delay();
        pwm.writeMicroseconds(12, 1450);
        //delay();
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        //delay();
        pwm.writeMicroseconds(12, 600);
        //delay();
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;

    case UNIFORM:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        //delay();
        pwm.writeMicroseconds(12, 1450);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(12, 600);
        //delay();
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;

    case VICTOR:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        
       }
       delay(2500);
    break;

    case WHISKY:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        //delay();
        pwm.writeMicroseconds(12, 1450);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(12, 600);
        //delay();
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;

    case XRAY:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        //delay();
        pwm.writeMicroseconds(12, 1450);
        pwm.writeMicroseconds(14, 800);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(12, 600);
        pwm.writeMicroseconds(14, 1500);
        //delay();
        pwm.writeMicroseconds(0, microsec);
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;

    case YANKEE:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        pwm.writeMicroseconds(1, microsec);
        pwm.writeMicroseconds(2, microsec);
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
       }
       delay(2500);
    break;

    case ZULU:
       for (uint16_t microsec = USMIN; microsec < USMAX; microsec++){
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
        //delay();
        //Thumb
        //delay();
        //Wrist
        //Elbow
       }
       delay(2500);
       for (uint16_t microsec = USMAX; microsec > USMIN; microsec--){
        //Wrist
        //Elbow
        //delay();
        //Thumb
        //delay();
        pwm.writeMicroseconds(4, microsec);
        pwm.writeMicroseconds(5, microsec);
        pwm.writeMicroseconds(7, microsec);
        pwm.writeMicroseconds(8, microsec);
        pwm.writeMicroseconds(10, microsec);
        pwm.writeMicroseconds(11, microsec);
       }
       delay(2500);
    break;
  }
  }
}

int pulseWidth(int angle){
  int pulse_wide, analog_value;
  pulse_wide = map(angle, 0, 180, MIN_PULSE_WIDTH, MAX_PULSE_WIDTH);
}
